How to upgrade s6
Keywords: s6 installation upgrade

s6
Software
skarnet.org

# What has changed in s6

## in 2.2.0.1

- skalibs dependency bumped to 2.3.6.1.
- execline dependency bumped to 2.1.3.1.

## in 2.2.0.0

- skalibs dependency bumped to 2.3.6.0.
- execline dependency bumped to 2.1.3.0.
- The internals of s6-supervise have changed; the `supervise/status` file ABI has changed and is not compatible with the daemontools/runit `supervise/status` files anymore. (This should not impact anything.)
- s6-supervise features a configurable timeout for `./finish` scripts, via the `./timeout-finish` file.
- s6-svwait, s6-svlisten1 and s6-svlisten can now wait for a `'D'` event, which means the `./finish` script has terminated.
- The deprecated `s6-notifywhenup` program has been removed.
- The syntax for synchronous s6-svc waiting has changed.

## in 2.1.6.0

- s6-svc now checks for the existence of `notification-fd` before accepting a `U` command.
- New `-X` option to s6-svc.
- Different meaning of SIGQUIT for s6-supervise: now the same as `s6-svc -X`.

## in 2.1.5.0

- s6-log now exits cleanly on SIGHUP.

## in 2.1.4.0

- skalibs dependency bumped to 2.3.5.1.
- execline dependency bumped to 2.1.2.2.
- The s6-notifywhenup command has been deprecated. Race-free readiness notification can now be implemented via the `notification-fd` file in a service directory.

## in 2.1.3.0

- skalibs dependency bumped to 2.3.2.0.
- execline dependency bumped to 2.1.1.0.
- New options to s6-envuidgid.

## in 2.1.2.0

- New options to s6-setsid.

## in 2.1.1.2

- skalibs dependency bumped to 2.3.1.0.
- execline dependency bumped to 2.1.0.0.
- Apart from that, this is a bugfix release. (The bump in dependencies is part of the bugfix.)

## in 2.1.1.1

Bugfix release, no important changes.

## in 2.1.1.0

- skalibs dependency bumped to 2.3.0.0.
- execline dependency bumped to 2.0.2.1.
- New functionality added to s6-log. Its syntax has been extended; some options are now marked as obsolescent.
- Access control instated in s6-fdholderd for listing

## in 2.1.0.1

Bugfix release, no important changes.

## in 2.1.0.0

- skalibs dependency bumped to 2.2.1.0.
- execline dependency bumped to 2.0.2.0.
- Unix domain socket utilities moved from the s6-networking package to s6.
- `./finish` argument for "service crashed" is now 256 instead of 255. Check your finish scripts!
- `supervise/status` now includes wstat information when the service died, and s6-svstat reports that information.
- s6-svstat now reports symbolic signal information by default, use `-n` to get the old behaviour.
- s6-log now properly calls execlineb with its installation prefix, in the slashpackage case.
- New commands: s6-svlisten and s6-svlisten1, to signal a service and wait on it without race condition.
- A brand new set of programs, `s6-fdholder*`, to perform fd-holding.
- Catchy blurb on intro page.

## in 2.0.1.0

- skalibs dependency bumped to 2.2.0.0.
- execline dependency bumped to 2.0.1.1.
- Better readiness notification management via s6-svwait -U.

## in 2.0.0.1

- skalibs dependency bumped to 2.1.0.0.

## in 2.0.0.0

- The build system has completely changed. It is now a standard `./configure && make && sudo make install` build system. See the enclosed INSTALL file for details.
- slashpackage is not activated by default.
- shared libraries are not used by default.
- skalibs dependency bumped to 2.0.0.0.
- execline dependency bumped to 2.0.0.0.
- s6-supervise does not create the `./event` fifodir as public. Subscriptions are restricted to users having the same gid as the s6-supervise process.
- The s6-notifywhenup program is a new addition.